using System;
using System.Collections.Generic;

        // Клас за представяне на книга
class Book
{
    public string Title { get; }
    public string Author { get; }
    public string ISBN { get; }
    public int PublicationYear { get; }

    public Book(string title, string author, string isbn, int publicationYear)
    {
        Title = title;
        Author = author;
        ISBN = isbn;
        PublicationYear = publicationYear;
    }

    public override string ToString()
    {
        return $"Title: {Title}, Author: {Author}, ISBN: {ISBN}, Year: {PublicationYear}";
    }
}

// Клас за представяне на библиотека 
class Library
{
    // Променете модификатора за достъп на 'books' на public
    public List<Book> books = new List<Book>();

    public void AddBook(Book book)
    {
        books.Add(book);
    }

    public void RemoveBook(string isbn)
    {
        books.RemoveAll(book => book.ISBN == isbn);
    }

    public void ListBooks()
    {
        foreach (var book in books)
        {
            Console.WriteLine(book);
        }
    }
}

// Клас за представяне на читател 
class Reader
{
    public string Name { get; }
    private List<Book> borrowedBooks = new List<Book>();

    public Reader(string name)
    {
        Name = name;
    }

    public void BorrowBook(Library library, string isbn)
    {
        var book = library.books.Find(b => b.ISBN == isbn);
        if (book != null)
        {
            borrowedBooks.Add(book);
            library.RemoveBook(isbn);
            Console.WriteLine($"{Name} borrowed: {book}");
        }
        else
        {
            Console.WriteLine("Book not found or already borrowed.");
        }
    }

    public void ReturnBook(Library library, Book book)
    {
        borrowedBooks.Remove(book);
        library.AddBook(book);
        Console.WriteLine($"{Name} returned: {book}");
    }

    public void ListBorrowedBooks()
    {
        Console.WriteLine($"{Name}'s borrowed books:");
        foreach (var book in borrowedBooks)
        {
            Console.WriteLine(book);
        }
    }
}

class LibraryManagementSystem
{
    static void Main(string[] args)
    {
        // Създаване на библиотека и добавяне на книги
        Library library = new Library();
        library.AddBook(new Book("Хамлет", " Уилям Шекспир", " 9786192511067", 2021));
        library.AddBook(new Book("Те бяха десет", " 	Агата Кристи", " 9789543897407", 2023));
        library.AddBook(new Book("Брулени хълмове", " Емили Бронте", " 9789542843306", 2023));

        // Създаване на читатели и извършване на операции с книги
        Reader reader1 = new Reader("Петър");
        Reader reader2 = new Reader("Рая");

        reader1.BorrowBook(library, "9786192511067");
        reader2.BorrowBook(library, "9789543897407");
        reader1.BorrowBook(library, "9789543897407");

        reader1.ListBorrowedBooks();
        reader2.ListBorrowedBooks();

        reader1.ReturnBook(library, new Book("Хамлет", " Уилям Шекспир", " 9786192511067", 2021));
        reader1.ListBorrowedBooks();

                // Извеждане на списъка с книги в библиотеката
        Console.WriteLine("Library books:");
        library.ListBooks();
    }
}
