import java.util.*;

public class LibraryManagementSystem {
    public static void main(String[] args) {
        // Клас за представяне на книга
        class Book {
            private String title;
            private String author;
            private String isbn;
            private int publicationYear;

            public Book(String title, String author, String isbn, int publicationYear) {
                this.title = title;
                this.author = author;
                this.isbn = isbn;
                this.publicationYear = publicationYear;
            }

            @Override
            public String toString() {
                return "Title: " + title + ", Author: " + author + ", ISBN: " + isbn + ", Year: " + publicationYear;
            }
        }

        // Клас за представяне на библиотека
        class Library {
            private List<Book> books = new ArrayList<>();

            public void addBook(Book book) {
                books.add(book);
            }

            public void removeBook(String isbn) {
                books.removeIf(book -> book.toString().contains(isbn));
            }

            public List<Book> getBooks() {
                return books;
            }
        }

        // Клас за представяне на читател
        class Reader {
            private String name;
            private Set<Book> borrowedBooks = new HashSet<>();

            public Reader(String name) {
                this.name = name;
            }

            public void borrowBook(Library library, String isbn) {
                List<Book> libraryBooks = library.getBooks();
                for (Book book : libraryBooks) {
                    if (book.toString().contains(isbn)) {
                        borrowedBooks.add(book);
                        library.removeBook(isbn);
                        System.out.println(name + " borrowed: " + book);
                        return;
                    }
                }
                System.out.println("Book not found or already borrowed.");
            }

            public void returnBook(Library library, Book book) {
                borrowedBooks.remove(book);
                library.addBook(book);
                System.out.println(name + " returned: " + book);
            }

            public void listBorrowedBooks() {
                System.out.println(name + "'s borrowed books:");
                for (Book book : borrowedBooks) {
                    System.out.println(book);
                }
            }
        }

        // Създаване на библиотека и добавяне на книги
        Library library = new Library();
        library.addBook(new Book("Hamlet", " William Shakespeare", " 9786192511067", 2021));
        library.addBook(new Book("There were ten of them", " 	Agatha Christie", " 9789543897407", 2023));
        library.addBook(new Book("Wuthering Heights", " Emily Bronte", " 9789542843306", 2023));

        // Създаване на читатели и извършване на операции с книги
        Reader reader1 = new Reader("Peter");
        Reader reader2 = new Reader("Raya");

        reader1.borrowBook(library, "9786192511067");
        reader2.borrowBook(library, "9789543897407");
        reader1.borrowBook(library, "9789543897407");

        reader1.listBorrowedBooks();
        reader2.listBorrowedBooks();

        reader1.returnBook(library, new Book("Hamlet", " William Shakespeare", " 9786192511067", 2021));
        reader1.listBorrowedBooks();

        // Извеждане на списъка с книги в библиотеката
        System.out.println("Library books:");
        List<Book> libraryBooks = library.getBooks();
        for (Book book : libraryBooks) {
            System.out.println(book);
        }
    }
}
